# Minfx

Neptune just announced the shutdown of its services.

Drop-in Replacement: just change

```
import neptune
```
to
```
import minfx.neptune_v2 as neptune
```

or

```
import neptune_scale
```
to
```
import minfx.neptune_v3 as neptune_scale
```


We will later publish how to generate new API token and sign up to the service.
